# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/',
                'doc_host': 'https://fastmonai.no',
                'git_url': 'https://github.com/MMIV-ML/fastMONAI',
                'lib_path': 'fastMONAI'},
  'syms': { 'fastMONAI.dataset_info': { 'fastMONAI.dataset_info.MedDataset': ('dataset_info.html#meddataset', 'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.__init__': ( 'dataset_info.html#meddataset.__init__',
                                                                                        'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._auto_cache_path': ( 'dataset_info.html#meddataset._auto_cache_path',
                                                                                                'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._create_data_frame': ( 'dataset_info.html#meddataset._create_data_frame',
                                                                                                  'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._get_data_info': ( 'dataset_info.html#meddataset._get_data_info',
                                                                                              'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._load_cache': ( 'dataset_info.html#meddataset._load_cache',
                                                                                           'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._process_with_cache': ( 'dataset_info.html#meddataset._process_with_cache',
                                                                                                   'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._save_cache': ( 'dataset_info.html#meddataset._save_cache',
                                                                                           'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset._visualize_single_case': ( 'dataset_info.html#meddataset._visualize_single_case',
                                                                                                      'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.calculate_target_size': ( 'dataset_info.html#meddataset.calculate_target_size',
                                                                                                     'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.fingerprint': ( 'dataset_info.html#meddataset.fingerprint',
                                                                                           'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.get_size_statistics': ( 'dataset_info.html#meddataset.get_size_statistics',
                                                                                                   'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.get_suggestion': ( 'dataset_info.html#meddataset.get_suggestion',
                                                                                              'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.get_volume_summary': ( 'dataset_info.html#meddataset.get_volume_summary',
                                                                                                  'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.summary': ( 'dataset_info.html#meddataset.summary',
                                                                                       'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.MedDataset.visualize_cases': ( 'dataset_info.html#meddataset.visualize_cases',
                                                                                               'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.get_class_weights': ( 'dataset_info.html#get_class_weights',
                                                                                      'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.preprocess_dataset': ( 'dataset_info.html#preprocess_dataset',
                                                                                       'fastMONAI/dataset_info.py'),
                                        'fastMONAI.dataset_info.suggest_patch_size': ( 'dataset_info.html#suggest_patch_size',
                                                                                       'fastMONAI/dataset_info.py')},
            'fastMONAI.external_data': { 'fastMONAI.external_data.MURLs': ('external_data.html#murls', 'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._create_nodule_df': ( 'external_data.html#_create_nodule_df',
                                                                                        'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._create_spine_df': ( 'external_data.html#_create_spine_df',
                                                                                       'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._dataset_available_locally': ( 'external_data.html#_dataset_available_locally',
                                                                                                 'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._df_sort_and_add_columns': ( 'external_data.html#_df_sort_and_add_columns',
                                                                                               'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._process_ixi_xls': ( 'external_data.html#_process_ixi_xls',
                                                                                       'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data._process_medmnist_img': ( 'external_data.html#_process_medmnist_img',
                                                                                            'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_example_endometrial_cancer_data': ( 'external_data.html#download_example_endometrial_cancer_data',
                                                                                                               'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_example_spine_data': ( 'external_data.html#download_example_spine_data',
                                                                                                  'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_ixi_data': ( 'external_data.html#download_ixi_data',
                                                                                        'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_ixi_tiny': ( 'external_data.html#download_ixi_tiny',
                                                                                        'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_medmnist3d_dataset': ( 'external_data.html#download_medmnist3d_dataset',
                                                                                                  'fastMONAI/external_data.py'),
                                         'fastMONAI.external_data.download_spine_test_data': ( 'external_data.html#download_spine_test_data',
                                                                                               'fastMONAI/external_data.py')},
            'fastMONAI.utils': { 'fastMONAI.utils.MLflowUIManager': ('utils.html#mlflowuimanager', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.__init__': ('utils.html#mlflowuimanager.__init__', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager._find_running_mlflow': ( 'utils.html#mlflowuimanager._find_running_mlflow',
                                                                                           'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.check_mlflow_installed': ( 'utils.html#mlflowuimanager.check_mlflow_installed',
                                                                                             'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.find_available_port': ( 'utils.html#mlflowuimanager.find_available_port',
                                                                                          'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.is_mlflow_running': ( 'utils.html#mlflowuimanager.is_mlflow_running',
                                                                                        'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.is_port_available': ( 'utils.html#mlflowuimanager.is_port_available',
                                                                                        'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.start_ui': ('utils.html#mlflowuimanager.start_ui', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.status': ('utils.html#mlflowuimanager.status', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.MLflowUIManager.stop': ('utils.html#mlflowuimanager.stop', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback': ('utils.html#modeltrackingcallback', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.__init__': ( 'utils.html#modeltrackingcallback.__init__',
                                                                                     'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback._build_config': ( 'utils.html#modeltrackingcallback._build_config',
                                                                                          'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback._extract_epoch_metrics': ( 'utils.html#modeltrackingcallback._extract_epoch_metrics',
                                                                                                   'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback._extract_training_params': ( 'utils.html#modeltrackingcallback._extract_training_params',
                                                                                                     'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback._log_split_df': ( 'utils.html#modeltrackingcallback._log_split_df',
                                                                                          'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback._register_pytorch_model': ( 'utils.html#modeltrackingcallback._register_pytorch_model',
                                                                                                    'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback._save_model_artifacts': ( 'utils.html#modeltrackingcallback._save_model_artifacts',
                                                                                                  'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.after_epoch': ( 'utils.html#modeltrackingcallback.after_epoch',
                                                                                        'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.after_fit': ( 'utils.html#modeltrackingcallback.after_fit',
                                                                                      'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.before_fit': ( 'utils.html#modeltrackingcallback.before_fit',
                                                                                       'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.extract_all_params': ( 'utils.html#modeltrackingcallback.extract_all_params',
                                                                                               'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.log_dataframe': ( 'utils.html#modeltrackingcallback.log_dataframe',
                                                                                          'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.log_metrics': ( 'utils.html#modeltrackingcallback.log_metrics',
                                                                                        'fastMONAI/utils.py'),
                                 'fastMONAI.utils.ModelTrackingCallback.log_metrics_table': ( 'utils.html#modeltrackingcallback.log_metrics_table',
                                                                                              'fastMONAI/utils.py'),
                                 'fastMONAI.utils._detect_patch_workflow': ('utils.html#_detect_patch_workflow', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils._extract_loss_name': ('utils.html#_extract_loss_name', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils._extract_model_name': ('utils.html#_extract_model_name', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils._extract_patch_config': ('utils.html#_extract_patch_config', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils._extract_size_from_transforms': ( 'utils.html#_extract_size_from_transforms',
                                                                                    'fastMONAI/utils.py'),
                                 'fastMONAI.utils._extract_standard_config': ('utils.html#_extract_standard_config', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.create_mlflow_callback': ('utils.html#create_mlflow_callback', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.load_patch_variables': ('utils.html#load_patch_variables', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.load_variables': ('utils.html#load_variables', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.print_colab_gpu_info': ('utils.html#print_colab_gpu_info', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.store_patch_variables': ('utils.html#store_patch_variables', 'fastMONAI/utils.py'),
                                 'fastMONAI.utils.store_variables': ('utils.html#store_variables', 'fastMONAI/utils.py')},
            'fastMONAI.vision_all': {},
            'fastMONAI.vision_augmentation': { 'fastMONAI.vision_augmentation.BinaryConverter': ( 'vision_augment.html#binaryconverter',
                                                                                                  'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.BinaryConverter.encodes': ( 'vision_augment.html#binaryconverter.encodes',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.BraTSMaskConverter': ( 'vision_augment.html#bratsmaskconverter',
                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.BraTSMaskConverter.encodes': ( 'vision_augment.html#bratsmaskconverter.encodes',
                                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.CustomDictTransform': ( 'vision_augment.html#customdicttransform',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.CustomDictTransform.__init__': ( 'vision_augment.html#customdicttransform.__init__',
                                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.CustomDictTransform.encodes': ( 'vision_augment.html#customdicttransform.encodes',
                                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.CustomDictTransform.tio_transform': ( 'vision_augment.html#customdicttransform.tio_transform',
                                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation': ( 'vision_augment.html#gpupatchaugmentation',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation.__call__': ( 'vision_augment.html#gpupatchaugmentation.__call__',
                                                                                                                'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation.__init__': ( 'vision_augment.html#gpupatchaugmentation.__init__',
                                                                                                                'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation.__repr__': ( 'vision_augment.html#gpupatchaugmentation.__repr__',
                                                                                                                'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation._apply_affine': ( 'vision_augment.html#gpupatchaugmentation._apply_affine',
                                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation._apply_anisotropy': ( 'vision_augment.html#gpupatchaugmentation._apply_anisotropy',
                                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation._apply_blur': ( 'vision_augment.html#gpupatchaugmentation._apply_blur',
                                                                                                                   'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation._apply_flip': ( 'vision_augment.html#gpupatchaugmentation._apply_flip',
                                                                                                                   'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation._apply_gamma': ( 'vision_augment.html#gpupatchaugmentation._apply_gamma',
                                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation._apply_intensity_scale': ( 'vision_augment.html#gpupatchaugmentation._apply_intensity_scale',
                                                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.GpuPatchAugmentation._apply_noise': ( 'vision_augment.html#gpupatchaugmentation._apply_noise',
                                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.NormalizeIntensity': ( 'vision_augment.html#normalizeintensity',
                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.NormalizeIntensity.__init__': ( 'vision_augment.html#normalizeintensity.__init__',
                                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.NormalizeIntensity.encodes': ( 'vision_augment.html#normalizeintensity.encodes',
                                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.NormalizeIntensity.tio_transform': ( 'vision_augment.html#normalizeintensity.tio_transform',
                                                                                                                   'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.OneOf': ( 'vision_augment.html#oneof',
                                                                                        'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.OneOf.__init__': ( 'vision_augment.html#oneof.__init__',
                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.PadOrCrop': ( 'vision_augment.html#padorcrop',
                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.PadOrCrop.__init__': ( 'vision_augment.html#padorcrop.__init__',
                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.PadOrCrop.encodes': ( 'vision_augment.html#padorcrop.encodes',
                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.PadOrCrop.tio_transform': ( 'vision_augment.html#padorcrop.tio_transform',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAffine': ( 'vision_augment.html#randomaffine',
                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAffine.__init__': ( 'vision_augment.html#randomaffine.__init__',
                                                                                                        'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAnisotropy': ( 'vision_augment.html#randomanisotropy',
                                                                                                   'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAnisotropy.__init__': ( 'vision_augment.html#randomanisotropy.__init__',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAnisotropy.encodes': ( 'vision_augment.html#randomanisotropy.encodes',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomAnisotropy.tio_transform': ( 'vision_augment.html#randomanisotropy.tio_transform',
                                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBiasField': ( 'vision_augment.html#randombiasfield',
                                                                                                  'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBiasField.__init__': ( 'vision_augment.html#randombiasfield.__init__',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBiasField.encodes': ( 'vision_augment.html#randombiasfield.encodes',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBiasField.tio_transform': ( 'vision_augment.html#randombiasfield.tio_transform',
                                                                                                                'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBlur': ( 'vision_augment.html#randomblur',
                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBlur.__init__': ( 'vision_augment.html#randomblur.__init__',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBlur.encodes': ( 'vision_augment.html#randomblur.encodes',
                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomBlur.tio_transform': ( 'vision_augment.html#randomblur.tio_transform',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomCutout': ( 'vision_augment.html#randomcutout',
                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomCutout.__init__': ( 'vision_augment.html#randomcutout.__init__',
                                                                                                        'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomCutout._get_fill_value': ( 'vision_augment.html#randomcutout._get_fill_value',
                                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomCutout.encodes': ( 'vision_augment.html#randomcutout.encodes',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomCutout.tio_transform': ( 'vision_augment.html#randomcutout.tio_transform',
                                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomElasticDeformation': ( 'vision_augment.html#randomelasticdeformation',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomElasticDeformation.__init__': ( 'vision_augment.html#randomelasticdeformation.__init__',
                                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomFlip': ( 'vision_augment.html#randomflip',
                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomFlip.__init__': ( 'vision_augment.html#randomflip.__init__',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGamma': ( 'vision_augment.html#randomgamma',
                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGamma.__init__': ( 'vision_augment.html#randomgamma.__init__',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGamma.encodes': ( 'vision_augment.html#randomgamma.encodes',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGamma.tio_transform': ( 'vision_augment.html#randomgamma.tio_transform',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGhosting': ( 'vision_augment.html#randomghosting',
                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGhosting.__init__': ( 'vision_augment.html#randomghosting.__init__',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGhosting.encodes': ( 'vision_augment.html#randomghosting.encodes',
                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomGhosting.tio_transform': ( 'vision_augment.html#randomghosting.tio_transform',
                                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomIntensityScale': ( 'vision_augment.html#randomintensityscale',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomIntensityScale.__init__': ( 'vision_augment.html#randomintensityscale.__init__',
                                                                                                                'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomIntensityScale.encodes': ( 'vision_augment.html#randomintensityscale.encodes',
                                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomIntensityScale.tio_transform': ( 'vision_augment.html#randomintensityscale.tio_transform',
                                                                                                                     'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomMotion': ( 'vision_augment.html#randommotion',
                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomMotion.__init__': ( 'vision_augment.html#randommotion.__init__',
                                                                                                        'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomMotion.encodes': ( 'vision_augment.html#randommotion.encodes',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomMotion.tio_transform': ( 'vision_augment.html#randommotion.tio_transform',
                                                                                                             'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomNoise': ( 'vision_augment.html#randomnoise',
                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomNoise.__init__': ( 'vision_augment.html#randomnoise.__init__',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomNoise.encodes': ( 'vision_augment.html#randomnoise.encodes',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomNoise.tio_transform': ( 'vision_augment.html#randomnoise.tio_transform',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomSpike': ( 'vision_augment.html#randomspike',
                                                                                              'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomSpike.__init__': ( 'vision_augment.html#randomspike.__init__',
                                                                                                       'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomSpike.encodes': ( 'vision_augment.html#randomspike.encodes',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RandomSpike.tio_transform': ( 'vision_augment.html#randomspike.tio_transform',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RescaleIntensity': ( 'vision_augment.html#rescaleintensity',
                                                                                                   'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RescaleIntensity.__init__': ( 'vision_augment.html#rescaleintensity.__init__',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RescaleIntensity.encodes': ( 'vision_augment.html#rescaleintensity.encodes',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.RescaleIntensity.tio_transform': ( 'vision_augment.html#rescaleintensity.tio_transform',
                                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.ZNormalization': ( 'vision_augment.html#znormalization',
                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.ZNormalization.__init__': ( 'vision_augment.html#znormalization.__init__',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.ZNormalization.encodes': ( 'vision_augment.html#znormalization.encodes',
                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.ZNormalization.tio_transform': ( 'vision_augment.html#znormalization.tio_transform',
                                                                                                               'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioNormalizeIntensity': ( 'vision_augment.html#_tionormalizeintensity',
                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioNormalizeIntensity.__init__': ( 'vision_augment.html#_tionormalizeintensity.__init__',
                                                                                                                  'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioNormalizeIntensity.apply_transform': ( 'vision_augment.html#_tionormalizeintensity.apply_transform',
                                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioRandomCutout': ( 'vision_augment.html#_tiorandomcutout',
                                                                                                   'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioRandomCutout.__init__': ( 'vision_augment.html#_tiorandomcutout.__init__',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioRandomCutout._apply_cutout': ( 'vision_augment.html#_tiorandomcutout._apply_cutout',
                                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioRandomCutout.apply_transform': ( 'vision_augment.html#_tiorandomcutout.apply_transform',
                                                                                                                   'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioRandomIntensityScale': ( 'vision_augment.html#_tiorandomintensityscale',
                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioRandomIntensityScale.__init__': ( 'vision_augment.html#_tiorandomintensityscale.__init__',
                                                                                                                    'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._TioRandomIntensityScale.apply_transform': ( 'vision_augment.html#_tiorandomintensityscale.apply_transform',
                                                                                                                           'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._build_rotation_matrix_3d': ( 'vision_augment.html#_build_rotation_matrix_3d',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._compute_patch_aug_params': ( 'vision_augment.html#_compute_patch_aug_params',
                                                                                                            'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._create_ellipsoid_mask': ( 'vision_augment.html#_create_ellipsoid_mask',
                                                                                                         'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation._foreground_masking': ( 'vision_augment.html#_foreground_masking',
                                                                                                      'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.do_pad_or_crop': ( 'vision_augment.html#do_pad_or_crop',
                                                                                                 'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.gpu_patch_augmentations': ( 'vision_augment.html#gpu_patch_augmentations',
                                                                                                          'fastMONAI/vision_augmentation.py'),
                                               'fastMONAI.vision_augmentation.suggest_patch_augmentations': ( 'vision_augment.html#suggest_patch_augmentations',
                                                                                                              'fastMONAI/vision_augmentation.py')},
            'fastMONAI.vision_core': { 'fastMONAI.vision_core.MedBase': ('vision_core.html#medbase', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.__copy__': ( 'vision_core.html#medbase.__copy__',
                                                                                   'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.__deepcopy__': ( 'vision_core.html#medbase.__deepcopy__',
                                                                                       'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.__new__': ( 'vision_core.html#medbase.__new__',
                                                                                  'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.__repr__': ( 'vision_core.html#medbase.__repr__',
                                                                                   'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.create': ( 'vision_core.html#medbase.create',
                                                                                 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.item_preprocessing': ( 'vision_core.html#medbase.item_preprocessing',
                                                                                             'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.new_empty': ( 'vision_core.html#medbase.new_empty',
                                                                                    'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedBase.show': ('vision_core.html#medbase.show', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedImage': ('vision_core.html#medimage', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MedMask': ('vision_core.html#medmask', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.MetaResolver': ('vision_core.html#metaresolver', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core._load_and_preprocess': ( 'vision_core.html#_load_and_preprocess',
                                                                                       'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core._multi_channel': ( 'vision_core.html#_multi_channel',
                                                                                 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core._preprocess': ('vision_core.html#_preprocess', 'fastMONAI/vision_core.py'),
                                       'fastMONAI.vision_core.med_img_reader': ( 'vision_core.html#med_img_reader',
                                                                                 'fastMONAI/vision_core.py')},
            'fastMONAI.vision_data': { 'fastMONAI.vision_data.MedDataBlock': ('vision_data.html#meddatablock', 'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedDataBlock.__init__': ( 'vision_data.html#meddatablock.__init__',
                                                                                        'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedImageDataLoaders': ( 'vision_data.html#medimagedataloaders',
                                                                                      'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedImageDataLoaders.from_df': ( 'vision_data.html#medimagedataloaders.from_df',
                                                                                              'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.MedMaskBlock': ('vision_data.html#medmaskblock', 'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.batch_pred_to_multiclass_mask': ( 'vision_data.html#batch_pred_to_multiclass_mask',
                                                                                                'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.plot_top_losses': ( 'vision_data.html#plot_top_losses',
                                                                                  'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.pred_to_binary_mask': ( 'vision_data.html#pred_to_binary_mask',
                                                                                      'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.pred_to_multiclass_mask': ( 'vision_data.html#pred_to_multiclass_mask',
                                                                                          'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.show_batch': ('vision_data.html#show_batch', 'fastMONAI/vision_data.py'),
                                       'fastMONAI.vision_data.show_results': ('vision_data.html#show_results', 'fastMONAI/vision_data.py')},
            'fastMONAI.vision_inference': { 'fastMONAI.vision_inference._do_resize': ( 'vision_inference.html#_do_resize',
                                                                                       'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference._to_original_orientation': ( 'vision_inference.html#_to_original_orientation',
                                                                                                     'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference._update_uid': ( 'vision_inference.html#_update_uid',
                                                                                        'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.compute_binary_tumor_volume': ( 'vision_inference.html#compute_binary_tumor_volume',
                                                                                                        'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.gradio_image_classifier': ( 'vision_inference.html#gradio_image_classifier',
                                                                                                    'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.inference': ( 'vision_inference.html#inference',
                                                                                      'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.keep_largest': ( 'vision_inference.html#keep_largest',
                                                                                         'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.load_system_resources': ( 'vision_inference.html#load_system_resources',
                                                                                                  'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.refine_binary_pred_mask': ( 'vision_inference.html#refine_binary_pred_mask',
                                                                                                    'fastMONAI/vision_inference.py'),
                                            'fastMONAI.vision_inference.save_series_pred': ( 'vision_inference.html#save_series_pred',
                                                                                             'fastMONAI/vision_inference.py')},
            'fastMONAI.vision_loss': { 'fastMONAI.vision_loss.CustomLoss': ( 'vision_loss_functions.html#customloss',
                                                                             'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.__call__': ( 'vision_loss_functions.html#customloss.__call__',
                                                                                      'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.__init__': ( 'vision_loss_functions.html#customloss.__init__',
                                                                                      'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.activation': ( 'vision_loss_functions.html#customloss.activation',
                                                                                        'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.CustomLoss.decodes': ( 'vision_loss_functions.html#customloss.decodes',
                                                                                     'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.TverskyFocalLoss': ( 'vision_loss_functions.html#tverskyfocalloss',
                                                                                   'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.TverskyFocalLoss.__init__': ( 'vision_loss_functions.html#tverskyfocalloss.__init__',
                                                                                            'fastMONAI/vision_loss.py'),
                                       'fastMONAI.vision_loss.TverskyFocalLoss.forward': ( 'vision_loss_functions.html#tverskyfocalloss.forward',
                                                                                           'fastMONAI/vision_loss.py')},
            'fastMONAI.vision_metrics': { 'fastMONAI.vision_metrics.AccumulatedDice': ( 'vision_metrics.html#accumulateddice',
                                                                                        'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedDice.__init__': ( 'vision_metrics.html#accumulateddice.__init__',
                                                                                                 'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedDice.accumulate': ( 'vision_metrics.html#accumulateddice.accumulate',
                                                                                                   'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedDice.name': ( 'vision_metrics.html#accumulateddice.name',
                                                                                             'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedDice.reset': ( 'vision_metrics.html#accumulateddice.reset',
                                                                                              'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedDice.value': ( 'vision_metrics.html#accumulateddice.value',
                                                                                              'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedMultiDice': ( 'vision_metrics.html#accumulatedmultidice',
                                                                                             'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedMultiDice.name': ( 'vision_metrics.html#accumulatedmultidice.name',
                                                                                                  'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.AccumulatedMultiDice.value': ( 'vision_metrics.html#accumulatedmultidice.value',
                                                                                                   'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.EMACheckpoint': ( 'vision_metrics.html#emacheckpoint',
                                                                                      'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.EMACheckpoint.__init__': ( 'vision_metrics.html#emacheckpoint.__init__',
                                                                                               'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.EMACheckpoint.after_epoch': ( 'vision_metrics.html#emacheckpoint.after_epoch',
                                                                                                  'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.EMACheckpoint.before_fit': ( 'vision_metrics.html#emacheckpoint.before_fit',
                                                                                                 'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.binary_dice_score': ( 'vision_metrics.html#binary_dice_score',
                                                                                          'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.binary_hausdorff_distance': ( 'vision_metrics.html#binary_hausdorff_distance',
                                                                                                  'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.binary_lesion_detection_rate': ( 'vision_metrics.html#binary_lesion_detection_rate',
                                                                                                     'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.binary_precision': ( 'vision_metrics.html#binary_precision',
                                                                                         'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.binary_sensitivity': ( 'vision_metrics.html#binary_sensitivity',
                                                                                           'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.binary_signed_rve': ( 'vision_metrics.html#binary_signed_rve',
                                                                                          'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.calculate_confusion_metrics': ( 'vision_metrics.html#calculate_confusion_metrics',
                                                                                                    'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.calculate_dsc': ( 'vision_metrics.html#calculate_dsc',
                                                                                      'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.calculate_haus': ( 'vision_metrics.html#calculate_haus',
                                                                                       'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.calculate_lesion_detection_rate': ( 'vision_metrics.html#calculate_lesion_detection_rate',
                                                                                                        'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.calculate_signed_rve': ( 'vision_metrics.html#calculate_signed_rve',
                                                                                             'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_dice_score': ( 'vision_metrics.html#multi_dice_score',
                                                                                         'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_hausdorff_distance': ( 'vision_metrics.html#multi_hausdorff_distance',
                                                                                                 'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_lesion_detection_rate': ( 'vision_metrics.html#multi_lesion_detection_rate',
                                                                                                    'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_precision': ( 'vision_metrics.html#multi_precision',
                                                                                        'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_sensitivity': ( 'vision_metrics.html#multi_sensitivity',
                                                                                          'fastMONAI/vision_metrics.py'),
                                          'fastMONAI.vision_metrics.multi_signed_rve': ( 'vision_metrics.html#multi_signed_rve',
                                                                                         'fastMONAI/vision_metrics.py')},
            'fastMONAI.vision_patch': { 'fastMONAI.vision_patch.MedPatchDataLoader': ( 'vision_patch.html#medpatchdataloader',
                                                                                       'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.__del__': ( 'vision_patch.html#medpatchdataloader.__del__',
                                                                                               'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.__enter__': ( 'vision_patch.html#medpatchdataloader.__enter__',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.__exit__': ( 'vision_patch.html#medpatchdataloader.__exit__',
                                                                                                'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.__init__': ( 'vision_patch.html#medpatchdataloader.__init__',
                                                                                                'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.__iter__': ( 'vision_patch.html#medpatchdataloader.__iter__',
                                                                                                'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.__len__': ( 'vision_patch.html#medpatchdataloader.__len__',
                                                                                               'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.close': ( 'vision_patch.html#medpatchdataloader.close',
                                                                                             'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.dataset': ( 'vision_patch.html#medpatchdataloader.dataset',
                                                                                               'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.device': ( 'vision_patch.html#medpatchdataloader.device',
                                                                                              'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.one_batch': ( 'vision_patch.html#medpatchdataloader.one_batch',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoader.to': ( 'vision_patch.html#medpatchdataloader.to',
                                                                                          'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders': ( 'vision_patch.html#medpatchdataloaders',
                                                                                        'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.__del__': ( 'vision_patch.html#medpatchdataloaders.__del__',
                                                                                                'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.__enter__': ( 'vision_patch.html#medpatchdataloaders.__enter__',
                                                                                                  'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.__exit__': ( 'vision_patch.html#medpatchdataloaders.__exit__',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.__getitem__': ( 'vision_patch.html#medpatchdataloaders.__getitem__',
                                                                                                    'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.__init__': ( 'vision_patch.html#medpatchdataloaders.__init__',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.__iter__': ( 'vision_patch.html#medpatchdataloaders.__iter__',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.__len__': ( 'vision_patch.html#medpatchdataloaders.__len__',
                                                                                                'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.apply_reorder': ( 'vision_patch.html#medpatchdataloaders.apply_reorder',
                                                                                                      'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.bs': ( 'vision_patch.html#medpatchdataloaders.bs',
                                                                                           'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.close': ( 'vision_patch.html#medpatchdataloaders.close',
                                                                                              'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.cpu': ( 'vision_patch.html#medpatchdataloaders.cpu',
                                                                                            'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.cuda': ( 'vision_patch.html#medpatchdataloaders.cuda',
                                                                                             'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.device': ( 'vision_patch.html#medpatchdataloaders.device',
                                                                                               'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.from_df': ( 'vision_patch.html#medpatchdataloaders.from_df',
                                                                                                'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.new_empty': ( 'vision_patch.html#medpatchdataloaders.new_empty',
                                                                                                  'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.one_batch': ( 'vision_patch.html#medpatchdataloaders.one_batch',
                                                                                                  'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.patch_config': ( 'vision_patch.html#medpatchdataloaders.patch_config',
                                                                                                     'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.show_batch': ( 'vision_patch.html#medpatchdataloaders.show_batch',
                                                                                                   'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.split_df': ( 'vision_patch.html#medpatchdataloaders.split_df',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.target_spacing': ( 'vision_patch.html#medpatchdataloaders.target_spacing',
                                                                                                       'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.to': ( 'vision_patch.html#medpatchdataloaders.to',
                                                                                           'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.train': ( 'vision_patch.html#medpatchdataloaders.train',
                                                                                              'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.train_ds': ( 'vision_patch.html#medpatchdataloaders.train_ds',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.valid': ( 'vision_patch.html#medpatchdataloaders.valid',
                                                                                              'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.MedPatchDataLoaders.valid_ds': ( 'vision_patch.html#medpatchdataloaders.valid_ds',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.PatchConfig': ( 'vision_patch.html#patchconfig',
                                                                                'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.PatchConfig.__post_init__': ( 'vision_patch.html#patchconfig.__post_init__',
                                                                                              'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.PatchConfig.from_dataset': ( 'vision_patch.html#patchconfig.from_dataset',
                                                                                             'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.PatchInferenceEngine': ( 'vision_patch.html#patchinferenceengine',
                                                                                         'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.PatchInferenceEngine.__init__': ( 'vision_patch.html#patchinferenceengine.__init__',
                                                                                                  'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.PatchInferenceEngine.predict': ( 'vision_patch.html#patchinferenceengine.predict',
                                                                                                 'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.PatchInferenceEngine.to': ( 'vision_patch.html#patchinferenceengine.to',
                                                                                            'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch._extract_tio_transform': ( 'vision_patch.html#_extract_tio_transform',
                                                                                           'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch._get_default_device': ( 'vision_patch.html#_get_default_device',
                                                                                        'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch._normalize_patch_overlap': ( 'vision_patch.html#_normalize_patch_overlap',
                                                                                             'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch._predict_patch_tta': ( 'vision_patch.html#_predict_patch_tta',
                                                                                       'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch._warn_config_override': ( 'vision_patch.html#_warn_config_override',
                                                                                          'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.create_patch_sampler': ( 'vision_patch.html#create_patch_sampler',
                                                                                         'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.create_subjects_dataset': ( 'vision_patch.html#create_subjects_dataset',
                                                                                            'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.med_to_subject': ( 'vision_patch.html#med_to_subject',
                                                                                   'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.normalize_patch_transforms': ( 'vision_patch.html#normalize_patch_transforms',
                                                                                               'fastMONAI/vision_patch.py'),
                                        'fastMONAI.vision_patch.patch_inference': ( 'vision_patch.html#patch_inference',
                                                                                    'fastMONAI/vision_patch.py')},
            'fastMONAI.vision_plot': { 'fastMONAI.vision_plot._get_slice': ('vision_plot.html#_get_slice', 'fastMONAI/vision_plot.py'),
                                       'fastMONAI.vision_plot.find_max_slice': ( 'vision_plot.html#find_max_slice',
                                                                                 'fastMONAI/vision_plot.py'),
                                       'fastMONAI.vision_plot.show_med_img': ('vision_plot.html#show_med_img', 'fastMONAI/vision_plot.py'),
                                       'fastMONAI.vision_plot.show_segmentation_comparison': ( 'vision_plot.html#show_segmentation_comparison',
                                                                                               'fastMONAI/vision_plot.py'),
                                       'fastMONAI.vision_plot.validate_anatomical_plane': ( 'vision_plot.html#validate_anatomical_plane',
                                                                                            'fastMONAI/vision_plot.py')}}}
